@@ -4,9 +4,9 @@
     'name': 'Account Statement',
     'name_de_DE': 'Buchhaltung Bankauszüge',
     'name_es_CO': 'Estado de Cuentas',
-    'name_es_ES': 'Estado de Cuentas',
+    'name_es_ES': 'Estado de cuentas',
     'name_fr_FR': 'Relevé comptable',
-    'version': '1.2.0',
+    'version': '1.4.1',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -21,7 +21,7 @@
     - Estado de cuentas
     - Diario de estado de cuentas
 ''',
-    'description_es_ES': '''Módulo Financiero y Contable con:
+    'description_es_ES': '''Módulo financiero y contable con:
     - Estado de cuentas
     - Diario de estado de cuentas
 ''',
