@@ -19,9 +19,10 @@ class Statement(ModelWorkflow, ModelSQL, ModelView):
     currency_digits = fields.Function('get_currency_digits', type='integer',
             string='Currency Digits', on_change_with=['journal'])
     date = fields.Date('Date', required=True, states=_STATES, select=1)
-    start_balance = fields.Numeric('Start Balance', digits=(16, 2),
-            states=_STATES)
-    end_balance = fields.Numeric('End Balance', digits=(16, 2), states=_STATES)
+    start_balance = fields.Numeric('Start Balance', digits="(16, currency_digits)",
+            states=_STATES, depends=['currency_digits'])
+    end_balance = fields.Numeric('End Balance', digits="(16, currency_digits)",
+            states=_STATES, depends=['currency_digits'])
     lines = fields.One2Many('account.statement.line', 'statement',
             'Transactions', states={
                 'readonly': "(state != 'draft') or (not bool(journal))",
@@ -286,13 +287,13 @@ class Line(ModelSQL, ModelView):
     party = fields.Many2One('party.party', 'Party',
             on_change=['amount', 'party', 'invoice'])
     account = fields.Many2One('account.account', 'Account', required=True,
-            on_change=['account', 'invoice'])
+            on_change=['account', 'invoice'], domain=[('kind', '!=', 'view')])
     description = fields.Char('Description')
     move = fields.Many2One('account.move', 'Account Move', readonly=True)
     invoice = fields.Many2One('account.invoice', 'Invoice',
-            domain="[('party', '=', party), ('account', '=', account)] " \
-                    "+ (_parent_statement.state == 'draft' and " \
-                        "[('state', '=', 'open')] or [])",
+            domain=["('party', '=', party)", "('account', '=', account)",
+                "('state', '=', _parent_statement.state == 'draft' and " \
+                        "'open' or False)"],
             states={
                 'readonly': "not bool(amount)",
             })
